@@ -85,7 +85,7 @@ static const gchar** special_cn[] = {special_cn_0,
                                      special_cn_1,
                                      special_cn_2,
                                      special_cn_3, NULL};
-static osso_context_t *osso_context;
+/*static osso_context_t *osso_context;*/
 static gboolean chinese_mode;
 
 typedef struct
@@ -250,8 +250,8 @@ module_init(GTypeModule *module)
                               HILDON_IM_TYPE_PLUGIN,
                               &plugin_info);
   chinese_mode = TRUE;
-  osso_context = osso_initialize("org.maemo.fcitm", VERSION, TRUE, NULL);
-  osso_hw_set_event_cb(osso_context, NULL, power_off_save_data, NULL);
+/*  osso_context = osso_initialize("org.maemo.fcitm", VERSION, TRUE, NULL);
+  osso_hw_set_event_cb(osso_context, NULL, power_off_save_data, NULL);*/
 }
 
 /*
@@ -450,11 +450,11 @@ static void LogToFile (const gchar *log_domain, GLogLevelFlags log_level, const
   fclose (logfile);
 }
 #endif
-static void power_off_save_data(osso_hw_state_t *state, gpointer data)
+/*static void power_off_save_data(osso_hw_state_t *state, gpointer data)
 {
   if(state->shutdown_ind)
     SavePYIndex();
-}
+}*/
 static void
 hildon_im_fcitx_fkb_enable (HildonIMPlugin *plugin,gboolean init)
 {
