@@ -273,8 +273,6 @@ static Bool LoadPYOtherDict(void)
     FILE *fp;
     int i, j, k, iLen;
     uint iIndex;
-//    PyFreq *pyFreqTemp, *pPyFreq;
-//    HZ *HZTemp, *pHZ;
 
     bPYOtherDictLoaded = True;
 
@@ -297,7 +295,9 @@ static Bool LoadPYOtherDict(void)
             fread(&k, sizeof(int), 1, fp);
             fread(&iIndex, sizeof(uint), 1, fp);
             fread(&iLen, sizeof(uint), 1, fp);
-
+            /* data is bad, break */
+            if(i<0 || i>=iCounter || j<0 || j>=iCounter || k<0 || k>=iCounter)
+                break;
             if (i < iPYFACount) {
                 if (j < PYFAList[i].iBase) {
                     if (k < PYFAList[i].pyBase[j].iPhrase) {
